@@ -1,4 +1,4 @@
-#  Copyright (c) 2018 by Rocky Bernstein
+#  Copyright (c) 2018-2019 by Rocky Bernstein
 #
 #  This program is free software; you can redistribute it and/or
 #  modify it under the terms of the GNU General Public License
@@ -225,7 +225,9 @@ def get_instructions_bytes(bytecode, opc, varnames=None, names=None, constants=N
     # multiple elements on a single pass through the loop
     n = len(bytecode)
     i = 0
+    extended_arg_count  = 0
     extended_arg = 0
+    extended_arg_size = op_size(opc.EXTENDED_ARG, opc)
     while i < n:
         op = code2num(bytecode, i)
 
@@ -295,9 +297,11 @@ def get_instructions_bytes(bytecode, opc, varnames=None, names=None, constants=N
             i += 1
 
         opname = opc.opname[op]
-        inst_size = op_size(op, opc)
+        inst_size = op_size(op, opc) + (extended_arg_count * extended_arg_size)
         yield Instruction(opname, op, optype, inst_size, arg, argval, argrepr,
-                          has_arg, offset, starts_line, is_jump_target)
+                          has_arg, offset, starts_line, is_jump_target,
+                          extended_arg_count != 0)
+        extended_arg_count = extended_arg_count + 1 if op == opc.EXTENDED_ARG else 0
 
 def op_has_argument(op, opc):
     return op >= opc.HAVE_ARGUMENT
@@ -305,8 +309,6 @@ def op_has_argument(op, opc):
 def next_offset(op, opc, offset):
     return offset + instruction_size(op, opc)
 
-# FIXME: this would better be called an instr_size
-# since it is about instructions, not opcodes
 def instruction_size(op, opc):
     """For a given opcode, `op`, in opcode module `opc`,
     return the size, in bytes, of an `op` instruction.
@@ -324,7 +326,7 @@ op_size = instruction_size
 
 
 _Instruction = namedtuple("_Instruction",
-     "opname opcode optype inst_size arg argval argrepr has_arg offset starts_line is_jump_target")
+     "opname opcode optype inst_size arg argval argrepr has_arg offset starts_line is_jump_target has_extended_arg")
 
 class Instruction(_Instruction):
     """Details for a bytecode operation
@@ -345,6 +347,8 @@ class Instruction(_Instruction):
          offset - start index of operation within bytecode sequence
          starts_line - line started by this opcode (if any), otherwise None
          is_jump_target - True if other code jumps to here, otherwise False
+         has_extended_arg - True if the instruction was built from EXTENDED_ARG
+                            opcodes
     """
     # FIXME: remove has_arg from initialization but keep it as a field.
 
@@ -444,7 +448,7 @@ class Instruction(_Instruction):
     # FIXME: figure out how to do disassemble passing in opnames
 
 class Bytecode(object):
-    """The bytecode operations of a piece of code
+    """Bytecode operations involving a Python code object.
 
     Instantiate this with a function, method, string of code, or a code object
     (as returned by compile()).
