@@ -97,6 +97,9 @@ op_imports = {
     '3.7.0' : opcode_37,
     3.7     : opcode_37,
     '3.8.0alpha0' : opcode_38,
+    '3.8.0a0': opcode_38,
+    '3.8.0a3+': opcode_38,
+    '3.8.0alpha3': opcode_38,
     '3.8' : opcode_38,
 
     '2.6pypy':  opcode_26pypy,
